#!/usr/bin/env python
# -*- coding: utf-8 -*-

#-----------------------------------------------------------------------------
# Boilerplate
#-----------------------------------------------------------------------------
from __future__ import absolute_import, division, print_function, unicode_literals

#-----------------------------------------------------------------------------
# Imports
#-----------------------------------------------------------------------------
import numpy as np
import matplotlib._cm_listed as mplcmaps

# -------------------------------------------------------------------------------------------------
#  Categorical Palettes
# -------------------------------------------------------------------------------------------------

# Categorical color palettes pastel and vibrant sourced from http://colorbrewer2.org/
_cat_pastel_data = ['#8dd3c7', '#ffffb3', '#bebada', '#fb8072', '#80b1d3', '#fdb462', '#b3de69',
                    '#fccde5', '#d9d9d9', '#bc80bd', '#ccebc5', '#ffed6f']
_cat_vibrant_data = ['#a6cee3', '#1f78b4', '#b2df8a', '#33a02c', '#fb9a99', '#e31a1c', '#fdbf6f',
                     '#ff7f00', '#cab2d6', '#6a3d9a', '#ffff99', '#b15928']

# Categorical color palette dark sourced from Seaborn
# http://stanford.edu/~mwaskom/software/seaborn/index.html
_cat_dark_data = ['#001C7F', '#017517', '#8C0900', '#7600A1', '#B8860B', '#006374']

# Define a dictionary pointing to the right data
cat_palettes = {}
for (name, data) in (('cat_pastel', _cat_pastel_data),
                     ('cat_vibrant', _cat_vibrant_data),
                     ('cat_dark', _cat_dark_data)):
    cat_palettes[name] = data

# Define a list of available palettes
avail_palettes = [palette for palette in cat_palettes]

# -------------------------------------------------------------------------------------------------
#  Continuous Colormaps
# -------------------------------------------------------------------------------------------------

_topo1_data = np.array([[1.000, 1.000, 1.000],
                        [1.000, 1.000, 1.000],
                        [0.992, 0.988, 0.992],
                        [0.992, 0.988, 0.992],
                        [0.984, 0.988, 0.984],
                        [0.976, 0.980, 0.973],
                        [0.969, 0.980, 0.961],
                        [0.973, 0.980, 0.965],
                        [0.953, 0.969, 0.941],
                        [0.949, 0.969, 0.933],
                        [0.945, 0.969, 0.933],
                        [0.933, 0.961, 0.918],
                        [0.933, 0.961, 0.918],
                        [0.929, 0.961, 0.906],
                        [0.918, 0.949, 0.898],
                        [0.914, 0.949, 0.886],
                        [0.918, 0.953, 0.890],
                        [0.902, 0.945, 0.878],
                        [0.902, 0.945, 0.875],
                        [0.898, 0.945, 0.863],
                        [0.890, 0.945, 0.859],
                        [0.882, 0.933, 0.843],
                        [0.875, 0.933, 0.835],
                        [0.871, 0.933, 0.835],
                        [0.859, 0.922, 0.816],
                        [0.859, 0.922, 0.812],
                        [0.851, 0.922, 0.804],
                        [0.839, 0.910, 0.796],
                        [0.835, 0.910, 0.788],
                        [0.835, 0.910, 0.784],
                        [0.820, 0.902, 0.765],
                        [0.816, 0.902, 0.765],
                        [0.800, 0.894, 0.749],
                        [0.792, 0.882, 0.737],
                        [0.788, 0.882, 0.725],
                        [0.780, 0.882, 0.718],
                        [0.776, 0.882, 0.714],
                        [0.765, 0.871, 0.702],
                        [0.765, 0.871, 0.698],
                        [0.761, 0.871, 0.694],
                        [0.753, 0.863, 0.682],
                        [0.749, 0.863, 0.675],
                        [0.749, 0.867, 0.675],
                        [0.737, 0.855, 0.663],
                        [0.733, 0.851, 0.659],
                        [0.733, 0.855, 0.655],
                        [0.722, 0.847, 0.639],
                        [0.722, 0.847, 0.639],
                        [0.722, 0.847, 0.639],
                        [0.710, 0.835, 0.627],
                        [0.710, 0.835, 0.627],
                        [0.702, 0.835, 0.620],
                        [0.698, 0.835, 0.608],
                        [0.698, 0.835, 0.608],
                        [0.702, 0.835, 0.608],
                        [0.714, 0.847, 0.616],
                        [0.718, 0.847, 0.616],
                        [0.718, 0.847, 0.616],
                        [0.729, 0.855, 0.620],
                        [0.733, 0.855, 0.620],
                        [0.737, 0.855, 0.620],
                        [0.741, 0.867, 0.627],
                        [0.745, 0.867, 0.627],
                        [0.749, 0.867, 0.631],
                        [0.765, 0.871, 0.639],
                        [0.765, 0.871, 0.639],
                        [0.776, 0.882, 0.647],
                        [0.776, 0.882, 0.647],
                        [0.780, 0.882, 0.643],
                        [0.796, 0.894, 0.655],
                        [0.796, 0.894, 0.655],
                        [0.804, 0.898, 0.655],
                        [0.812, 0.898, 0.659],
                        [0.824, 0.906, 0.667],
                        [0.824, 0.906, 0.667],
                        [0.831, 0.910, 0.671],
                        [0.843, 0.922, 0.678],
                        [0.847, 0.922, 0.678],
                        [0.851, 0.922, 0.682],
                        [0.867, 0.933, 0.686],
                        [0.871, 0.933, 0.686],
                        [0.875, 0.933, 0.686],
                        [0.886, 0.949, 0.698],
                        [0.890, 0.949, 0.698],
                        [0.894, 0.949, 0.698],
                        [0.910, 0.957, 0.710],
                        [0.914, 0.957, 0.710],
                        [0.918, 0.957, 0.706],
                        [0.925, 0.969, 0.714],
                        [0.929, 0.969, 0.714],
                        [0.937, 0.969, 0.725],
                        [0.941, 0.976, 0.733],
                        [0.949, 0.976, 0.733],
                        [0.949, 0.973, 0.733],
                        [0.949, 0.973, 0.733],
                        [0.965, 0.984, 0.737],
                        [0.969, 0.984, 0.737],
                        [0.969, 0.984, 0.737],
                        [0.980, 0.992, 0.745],
                        [0.984, 0.992, 0.745],
                        [0.988, 0.992, 0.745],
                        [1.000, 1.000, 0.753],
                        [1.000, 1.000, 0.753],
                        [0.992, 0.988, 0.745],
                        [0.996, 0.988, 0.745],
                        [0.992, 0.988, 0.745],
                        [0.988, 0.980, 0.737],
                        [0.988, 0.980, 0.741],
                        [0.988, 0.976, 0.741],
                        [0.976, 0.965, 0.737],
                        [0.976, 0.961, 0.737],
                        [0.976, 0.961, 0.737],
                        [0.969, 0.949, 0.725],
                        [0.969, 0.949, 0.725],
                        [0.973, 0.945, 0.725],
                        [0.961, 0.937, 0.722],
                        [0.961, 0.937, 0.722],
                        [0.961, 0.933, 0.722],
                        [0.961, 0.933, 0.722],
                        [0.953, 0.918, 0.714],
                        [0.953, 0.918, 0.710],
                        [0.953, 0.918, 0.714],
                        [0.937, 0.902, 0.702],
                        [0.937, 0.902, 0.702],
                        [0.937, 0.898, 0.702],
                        [0.925, 0.886, 0.694],
                        [0.925, 0.882, 0.694],
                        [0.925, 0.882, 0.694],
                        [0.910, 0.863, 0.678],
                        [0.910, 0.863, 0.678],
                        [0.910, 0.863, 0.678],
                        [0.902, 0.847, 0.671],
                        [0.902, 0.847, 0.671],
                        [0.898, 0.843, 0.671],
                        [0.886, 0.831, 0.663],
                        [0.886, 0.827, 0.663],
                        [0.886, 0.827, 0.663],
                        [0.886, 0.824, 0.659],
                        [0.875, 0.816, 0.655],
                        [0.875, 0.816, 0.655],
                        [0.875, 0.812, 0.651],
                        [0.867, 0.804, 0.643],
                        [0.867, 0.800, 0.643],
                        [0.867, 0.800, 0.647],
                        [0.859, 0.788, 0.639],
                        [0.859, 0.784, 0.635],
                        [0.859, 0.784, 0.635],
                        [0.851, 0.776, 0.627],
                        [0.851, 0.776, 0.627],
                        [0.851, 0.773, 0.627],
                        [0.839, 0.765, 0.624],
                        [0.839, 0.757, 0.624],
                        [0.839, 0.757, 0.624],
                        [0.839, 0.753, 0.612],
                        [0.831, 0.749, 0.608],
                        [0.831, 0.749, 0.608],
                        [0.831, 0.745, 0.596],
                        [0.831, 0.741, 0.596],
                        [0.831, 0.737, 0.588],
                        [0.831, 0.737, 0.592],
                        [0.831, 0.741, 0.588],
                        [0.831, 0.733, 0.584],
                        [0.831, 0.733, 0.580],
                        [0.827, 0.733, 0.573],
                        [0.827, 0.733, 0.573],
                        [0.827, 0.729, 0.565],
                        [0.827, 0.729, 0.565],
                        [0.816, 0.718, 0.553],
                        [0.816, 0.718, 0.553],
                        [0.816, 0.718, 0.549],
                        [0.816, 0.714, 0.545],
                        [0.816, 0.714, 0.541],
                        [0.816, 0.710, 0.533],
                        [0.820, 0.710, 0.533],
                        [0.816, 0.706, 0.522],
                        [0.816, 0.706, 0.525],
                        [0.816, 0.710, 0.518],
                        [0.816, 0.706, 0.514],
                        [0.816, 0.702, 0.506],
                        [0.808, 0.698, 0.494],
                        [0.808, 0.694, 0.486],
                        [0.808, 0.690, 0.486],
                        [0.808, 0.690, 0.478],
                        [0.808, 0.690, 0.475],
                        [0.808, 0.690, 0.471],
                        [0.808, 0.686, 0.463],
                        [0.808, 0.686, 0.463],
                        [0.808, 0.682, 0.455],
                        [0.808, 0.682, 0.455],
                        [0.808, 0.678, 0.447],
                        [0.808, 0.678, 0.443],
                        [0.796, 0.675, 0.439],
                        [0.796, 0.671, 0.439],
                        [0.796, 0.667, 0.427],
                        [0.796, 0.667, 0.427],
                        [0.796, 0.663, 0.420],
                        [0.796, 0.663, 0.420],
                        [0.796, 0.659, 0.412],
                        [0.796, 0.663, 0.412],
                        [0.796, 0.663, 0.408],
                        [0.796, 0.663, 0.408],
                        [0.796, 0.659, 0.400],
                        [0.796, 0.659, 0.400],
                        [0.796, 0.663, 0.392],
                        [0.796, 0.667, 0.400],
                        [0.796, 0.667, 0.408],
                        [0.808, 0.678, 0.420],
                        [0.808, 0.682, 0.431],
                        [0.808, 0.686, 0.439],
                        [0.816, 0.690, 0.439],
                        [0.816, 0.694, 0.451],
                        [0.816, 0.698, 0.459],
                        [0.827, 0.710, 0.475],
                        [0.827, 0.710, 0.478],
                        [0.835, 0.718, 0.494],
                        [0.831, 0.722, 0.502],
                        [0.835, 0.725, 0.510],
                        [0.843, 0.737, 0.522],
                        [0.843, 0.737, 0.529],
                        [0.851, 0.749, 0.541],
                        [0.851, 0.753, 0.549],
                        [0.851, 0.757, 0.561],
                        [0.867, 0.769, 0.576],
                        [0.867, 0.773, 0.592],
                        [0.878, 0.796, 0.620],
                        [0.878, 0.796, 0.627],
                        [0.878, 0.800, 0.639],
                        [0.890, 0.812, 0.655],
                        [0.890, 0.816, 0.667],
                        [0.902, 0.827, 0.682],
                        [0.902, 0.835, 0.698],
                        [0.906, 0.835, 0.698],
                        [0.910, 0.847, 0.714],
                        [0.914, 0.851, 0.725],
                        [0.914, 0.855, 0.737],
                        [0.925, 0.867, 0.757],
                        [0.925, 0.871, 0.765],
                        [0.933, 0.882, 0.780],
                        [0.933, 0.886, 0.792],
                        [0.933, 0.886, 0.800],
                        [0.941, 0.898, 0.812],
                        [0.941, 0.898, 0.824],
                        [0.949, 0.914, 0.835],
                        [0.949, 0.914, 0.851],
                        [0.949, 0.918, 0.855],
                        [0.961, 0.933, 0.878],
                        [0.961, 0.933, 0.886],
                        [0.969, 0.949, 0.902],
                        [0.969, 0.949, 0.914],
                        [0.969, 0.953, 0.922],
                        [0.980, 0.969, 0.941],
                        [0.980, 0.969, 0.949],
                        [0.988, 0.984, 0.969],
                        [0.988, 0.988, 0.980],
                        [0.988, 0.988, 0.988],
                        [0.988, 0.988, 0.988]])

_topo2_data = np.array([[0.361, 0.596, 0.506],
                        [0.318, 0.565, 0.467],
                        [0.318, 0.565, 0.467],
                        [0.318, 0.569, 0.471],
                        [0.322, 0.576, 0.475],
                        [0.322, 0.576, 0.478],
                        [0.322, 0.576, 0.478],
                        [0.325, 0.584, 0.486],
                        [0.325, 0.588, 0.486],
                        [0.329, 0.592, 0.494],
                        [0.329, 0.596, 0.494],
                        [0.329, 0.596, 0.494],
                        [0.333, 0.608, 0.502],
                        [0.333, 0.608, 0.502],
                        [0.337, 0.612, 0.506],
                        [0.380, 0.639, 0.541],
                        [0.298, 0.596, 0.482],
                        [0.298, 0.596, 0.482],
                        [0.298, 0.596, 0.482],
                        [0.302, 0.604, 0.490],
                        [0.306, 0.608, 0.490],
                        [0.306, 0.612, 0.498],
                        [0.306, 0.612, 0.498],
                        [0.306, 0.616, 0.502],
                        [0.310, 0.627, 0.510],
                        [0.310, 0.627, 0.510],
                        [0.318, 0.635, 0.518],
                        [0.318, 0.635, 0.518],
                        [0.322, 0.643, 0.525],
                        [0.322, 0.643, 0.525],
                        [0.325, 0.647, 0.525],
                        [0.325, 0.655, 0.533],
                        [0.369, 0.678, 0.565],
                        [0.333, 0.671, 0.549],
                        [0.333, 0.667, 0.549],
                        [0.333, 0.671, 0.549],
                        [0.337, 0.678, 0.557],
                        [0.337, 0.678, 0.557],
                        [0.337, 0.678, 0.557],
                        [0.341, 0.690, 0.565],
                        [0.345, 0.702, 0.573],
                        [0.341, 0.702, 0.573],
                        [0.345, 0.702, 0.576],
                        [0.349, 0.710, 0.580],
                        [0.349, 0.710, 0.584],
                        [0.349, 0.710, 0.584],
                        [0.353, 0.722, 0.592],
                        [0.392, 0.737, 0.620],
                        [0.396, 0.745, 0.631],
                        [0.357, 0.733, 0.608],
                        [0.357, 0.733, 0.608],
                        [0.361, 0.741, 0.616],
                        [0.365, 0.745, 0.616],
                        [0.369, 0.749, 0.620],
                        [0.369, 0.749, 0.624],
                        [0.376, 0.761, 0.631],
                        [0.376, 0.761, 0.631],
                        [0.376, 0.765, 0.631],
                        [0.380, 0.769, 0.635],
                        [0.380, 0.769, 0.639],
                        [0.384, 0.780, 0.643],
                        [0.384, 0.780, 0.643],
                        [0.384, 0.780, 0.643],
                        [0.427, 0.800, 0.671],
                        [0.431, 0.812, 0.686],
                        [0.404, 0.800, 0.671],
                        [0.416, 0.812, 0.675],
                        [0.424, 0.812, 0.671],
                        [0.431, 0.812, 0.667],
                        [0.439, 0.812, 0.671],
                        [0.451, 0.820, 0.675],
                        [0.459, 0.820, 0.675],
                        [0.467, 0.820, 0.678],
                        [0.482, 0.831, 0.682],
                        [0.482, 0.831, 0.682],
                        [0.498, 0.831, 0.678],
                        [0.506, 0.839, 0.686],
                        [0.514, 0.839, 0.682],
                        [0.522, 0.839, 0.678],
                        [0.561, 0.859, 0.702],
                        [0.569, 0.859, 0.710],
                        [0.549, 0.851, 0.690],
                        [0.565, 0.859, 0.698],
                        [0.565, 0.859, 0.694],
                        [0.576, 0.859, 0.690],
                        [0.588, 0.871, 0.698],
                        [0.600, 0.871, 0.698],
                        [0.612, 0.871, 0.694],
                        [0.627, 0.878, 0.702],
                        [0.635, 0.878, 0.706],
                        [0.635, 0.878, 0.698],
                        [0.651, 0.890, 0.706],
                        [0.659, 0.890, 0.710],
                        [0.671, 0.890, 0.706],
                        [0.686, 0.902, 0.714],
                        [0.706, 0.906, 0.722],
                        [0.714, 0.906, 0.722],
                        [0.710, 0.902, 0.710],
                        [0.722, 0.910, 0.710],
                        [0.725, 0.910, 0.710],
                        [0.737, 0.910, 0.710],
                        [0.757, 0.925, 0.722],
                        [0.761, 0.925, 0.722],
                        [0.773, 0.925, 0.722],
                        [0.788, 0.933, 0.729],
                        [0.792, 0.933, 0.722],
                        [0.800, 0.933, 0.722],
                        [0.816, 0.949, 0.733],
                        [0.824, 0.949, 0.733],
                        [0.831, 0.949, 0.733],
                        [0.851, 0.957, 0.741],
                        [0.863, 0.961, 0.757],
                        [0.878, 0.965, 0.757],
                        [0.871, 0.957, 0.741],
                        [0.882, 0.969, 0.737],
                        [0.886, 0.969, 0.737],
                        [0.898, 0.969, 0.737],
                        [0.918, 0.976, 0.745],
                        [0.918, 0.976, 0.745],
                        [0.922, 0.976, 0.745],
                        [0.937, 0.984, 0.749],
                        [0.949, 0.984, 0.749],
                        [0.953, 0.984, 0.749],
                        [0.969, 0.992, 0.745],
                        [0.973, 0.992, 0.745],
                        [0.976, 0.992, 0.745],
                        [0.996, 1.000, 0.753],
                        [1.000, 1.000, 0.765],
                        [1.000, 1.000, 0.765],
                        [0.996, 0.988, 0.745],
                        [0.996, 0.988, 0.745],
                        [0.996, 0.988, 0.737],
                        [0.988, 0.980, 0.729],
                        [0.992, 0.980, 0.718],
                        [0.992, 0.980, 0.718],
                        [0.980, 0.965, 0.714],
                        [0.980, 0.965, 0.706],
                        [0.980, 0.965, 0.706],
                        [0.973, 0.949, 0.698],
                        [0.976, 0.949, 0.690],
                        [0.976, 0.949, 0.690],
                        [0.965, 0.937, 0.675],
                        [0.965, 0.937, 0.675],
                        [0.965, 0.941, 0.694],
                        [0.961, 0.925, 0.675],
                        [0.957, 0.918, 0.655],
                        [0.953, 0.918, 0.647],
                        [0.941, 0.902, 0.639],
                        [0.941, 0.902, 0.639],
                        [0.937, 0.902, 0.627],
                        [0.937, 0.902, 0.627],
                        [0.929, 0.886, 0.612],
                        [0.929, 0.882, 0.612],
                        [0.929, 0.882, 0.612],
                        [0.914, 0.867, 0.596],
                        [0.914, 0.867, 0.596],
                        [0.914, 0.867, 0.588],
                        [0.902, 0.847, 0.576],
                        [0.902, 0.847, 0.576],
                        [0.906, 0.851, 0.592],
                        [0.898, 0.835, 0.580],
                        [0.890, 0.831, 0.557],
                        [0.890, 0.827, 0.549],
                        [0.875, 0.808, 0.537],
                        [0.875, 0.808, 0.529],
                        [0.875, 0.808, 0.529],
                        [0.875, 0.808, 0.529],
                        [0.867, 0.788, 0.514],
                        [0.867, 0.788, 0.514],
                        [0.867, 0.784, 0.502],
                        [0.855, 0.769, 0.494],
                        [0.855, 0.769, 0.494],
                        [0.855, 0.769, 0.482],
                        [0.843, 0.749, 0.478],
                        [0.843, 0.745, 0.471],
                        [0.851, 0.761, 0.494],
                        [0.843, 0.749, 0.494],
                        [0.831, 0.729, 0.455],
                        [0.835, 0.729, 0.455],
                        [0.824, 0.718, 0.443],
                        [0.824, 0.718, 0.443],
                        [0.824, 0.718, 0.443],
                        [0.827, 0.714, 0.435],
                        [0.816, 0.698, 0.431],
                        [0.816, 0.698, 0.431],
                        [0.816, 0.698, 0.424],
                        [0.808, 0.682, 0.416],
                        [0.808, 0.678, 0.408],
                        [0.808, 0.678, 0.412],
                        [0.796, 0.667, 0.408],
                        [0.796, 0.667, 0.400],
                        [0.808, 0.682, 0.427],
                        [0.808, 0.686, 0.435],
                        [0.796, 0.667, 0.408],
                        [0.808, 0.675, 0.420],
                        [0.808, 0.678, 0.427],
                        [0.808, 0.682, 0.435],
                        [0.808, 0.682, 0.435],
                        [0.816, 0.690, 0.447],
                        [0.816, 0.690, 0.451],
                        [0.816, 0.694, 0.459],
                        [0.824, 0.706, 0.475],
                        [0.824, 0.706, 0.475],
                        [0.824, 0.706, 0.478],
                        [0.831, 0.718, 0.494],
                        [0.831, 0.718, 0.502],
                        [0.831, 0.718, 0.502],
                        [0.851, 0.745, 0.541],
                        [0.851, 0.749, 0.553],
                        [0.843, 0.733, 0.533],
                        [0.851, 0.745, 0.549],
                        [0.851, 0.749, 0.553],
                        [0.851, 0.753, 0.561],
                        [0.851, 0.757, 0.569],
                        [0.867, 0.769, 0.584],
                        [0.867, 0.773, 0.588],
                        [0.867, 0.776, 0.596],
                        [0.875, 0.788, 0.612],
                        [0.875, 0.788, 0.624],
                        [0.875, 0.792, 0.631],
                        [0.886, 0.808, 0.643],
                        [0.890, 0.808, 0.651],
                        [0.890, 0.812, 0.659],
                        [0.906, 0.835, 0.698],
                        [0.906, 0.835, 0.702],
                        [0.906, 0.835, 0.702],
                        [0.914, 0.847, 0.718],
                        [0.914, 0.851, 0.725],
                        [0.914, 0.855, 0.737],
                        [0.914, 0.855, 0.737],
                        [0.925, 0.867, 0.753],
                        [0.925, 0.871, 0.761],
                        [0.925, 0.871, 0.773],
                        [0.933, 0.886, 0.788],
                        [0.933, 0.886, 0.788],
                        [0.933, 0.886, 0.800],
                        [0.945, 0.902, 0.816],
                        [0.945, 0.902, 0.827],
                        [0.945, 0.902, 0.827],
                        [0.953, 0.918, 0.843],
                        [0.953, 0.922, 0.867],
                        [0.953, 0.922, 0.863],
                        [0.965, 0.933, 0.882],
                        [0.965, 0.933, 0.882],
                        [0.965, 0.937, 0.894],
                        [0.965, 0.941, 0.898],
                        [0.969, 0.953, 0.918],
                        [0.969, 0.957, 0.925],
                        [0.969, 0.957, 0.929],
                        [0.980, 0.969, 0.949],
                        [0.980, 0.969, 0.953],
                        [0.980, 0.973, 0.965],
                        [0.988, 0.984, 0.973],
                        [0.988, 0.988, 0.984],
                        [0.988, 0.988, 0.988],
                        [0.988, 0.988, 0.992]])

# Define a dictionary pointing to the right data
cont_cmaps = {}
for (name, data) in (('topo1', _topo1_data),
                     ('topo2', _topo2_data)):
    cont_cmaps[name] = data

# Define a list of cmaps that can be called
avail_cmaps = [cmap for cmap in cont_cmaps]
